@@ -317,7 +317,10 @@ Return the Elluminate I<Live!> Manager version
 =cut
 
 sub version {
-    return (my $self = shift)->server_details->version;
+    my $self = shift;
+    my $server_details = $self->server_details
+	or die "Unable to get server details is the Session Server (elive) running?\n";
+    return $server_details->version;
 }
 
 1;
